@@ -66,7 +66,7 @@ anova.summary.lm_mat <- function(...){
 #' categorical moderators for an `ma_psychmeta` object, as well as an ombnibus
 #' one-way ANOVA test (equal variance not assumed).
 #'
-#' Currently, samples across moderator levels are assumed to be indepdent.
+#' Currently, samples across moderator levels are assumed to be independent.
 #'
 #' @param object A psychmeta meta-analysis object.
 #' @param analyses Which analyses to to test moderators for? Can be either `"all"` to test moderators for all meta-analyses in the object (default) or a list containing one or more of the arguments `construct`, `construct_pair`, `pair_id`, `k_min`, and `N_min`. See [filter_ma()] for details. Note that `analysis_id` should not be used. If `k_min` is not supplied, it is set to 2.
@@ -74,7 +74,7 @@ anova.summary.lm_mat <- function(...){
 #' @param L A named list with with elements specifying set of linear contrasts for each variable in `moderators`. (Not yet implemented.)
 #' @param ma_obj2 A second psychmeta meta-analysis object to compare to `object` (Not yet implemented.)
 #' @param ma_method Meta-analytic methods to be included. Valid options are: "bb", "ic", and "ad"
-#' @param correction_type Types of meta-analytic corrections to be incldued. Valid options are: "ts", "vgx", and "vgy"
+#' @param correction_type Types of meta-analytic corrections to be included. Valid options are: "ts", "vgx", and "vgy"
 #' @param conf_level Confidence level to define the width of confidence intervals (defaults to value set when `object` was fit)
 #' @param ... Additional arguments.
 #'
@@ -116,7 +116,9 @@ anova.ma_psychmeta <- function(object, ..., analyses = "all",
                 select(-1, -.data$k) %>%
                 colnames()
 
-        if (length(moderators) == 0) stop("'object' contains no moderators or no moderators selected")
+        if (length(moderators) == 0) {
+          stop("Provided meta-analysis object contains no moderators or no moderators selected", call. = FALSE)
+        }
 
         if (is.null(conf_level)) conf_level <- attributes(object)$inputs$conf_level
 
